.modules-list{
    width: 100%;
    float: left;
    margin-top: 25px;
}
.container-helper p{
    font-size: 14px;
}
.container-helper h1{
    padding: 30px 0;
    font-weight: bold;
}
.container-helper h2, .container-helper h3{
    font-size: 25px;
    text-decoration: underline;
    padding: 20px 0 5px 0;
}
.container-helper h2:nth-child(2){
    padding-top: 0;
}
.container-helper .tab-content{
    padding: 0 60px;
}
.container-helper pre{
    background: #f5f5f5;
    border: 1px solid #ccc;
    border-radius: 3px;
    overflow-x: auto;
    padding: 5px 10px;
    word-wrap: normal;
    margin: 10px 0;
}
.container-helper ol, .container-helper ul{
    padding-left: 40px;
}

.user_guide_tree{
    min-width: 25%
}

.user_guide_tree{
    background-color: #DCDCDC;
    padding-top: 15px;
    padding-bottom: 15px;
}

.user_guide_tree .active{
    font-weight: bold;
}

.user_guide_tree ul{
    padding-left: 20px;
}

.fa-angle-down, .fa-angle-right{
    cursor: pointer;
}
.user_guide_tree .fa{
    padding-right: 7px;
}

.user_guide_tree i.fa{
    width: 5px;
}

.container-helper img{
    padding-top: 20px;
    padding-bottom: 20px;
}

.user_guide_content{
    min-width: 70%
}

@media screen and (max-width: 1500px){
    .container.container-helper{
        max-width: 1200px;
        min-width: inherit;
    }

    .user_guide_content {
        max-width: calc(100% - 356px);
        min-width: inherit;
    }

    .user_guide_tree {
        max-width: inherit;
        width: 300px;
    }
}